ScoreConsumer
=============

.. currentmodule:: pykeen.predict

.. autoclass:: ScoreConsumer
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ScoreConsumer.__call__
      ~ScoreConsumer.finalize

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: finalize
